@@ -51,31 +51,39 @@ CdMappingDb	*cd_mapping_db_new		(void);
 
 gboolean	 cd_mapping_db_load		(CdMappingDb	*mdb,
 						 const gchar	*filename,
-						 GError		**error);
+						 GError		**error)
+						 G_GNUC_WARN_UNUSED_RESULT;
 gboolean	 cd_mapping_db_empty		(CdMappingDb	*mdb,
-						 GError		**error);
+						 GError		**error)
+						 G_GNUC_WARN_UNUSED_RESULT;
 gboolean	 cd_mapping_db_clear_timestamp	(CdMappingDb	*mdb,
 						 const gchar	*device_id,
 						 const gchar	*profile_id,
-						 GError		**error);
+						 GError		**error)
+						 G_GNUC_WARN_UNUSED_RESULT;
 gboolean	 cd_mapping_db_add		(CdMappingDb	*mdb,
 						 const gchar	*device_id,
 						 const gchar	*profile_id,
-						 GError		**error);
+						 GError		**error)
+						 G_GNUC_WARN_UNUSED_RESULT;
 gboolean	 cd_mapping_db_remove		(CdMappingDb	*mdb,
 						 const gchar	*device_id,
 						 const gchar	*profile_id,
-						 GError		**error);
+						 GError		**error)
+						 G_GNUC_WARN_UNUSED_RESULT;
 GPtrArray	*cd_mapping_db_get_profiles	(CdMappingDb	*mdb,
 						 const gchar	*device_id,
-						 GError		**error);
+						 GError		**error)
+						 G_GNUC_WARN_UNUSED_RESULT;
 GPtrArray	*cd_mapping_db_get_devices	(CdMappingDb	*mdb,
 						 const gchar	*profile_id,
-						 GError		**error);
+						 GError		**error)
+						 G_GNUC_WARN_UNUSED_RESULT;
 guint64		 cd_mapping_db_get_timestamp	(CdMappingDb	*mdb,
 						 const gchar	*device_id,
 						 const gchar	*profile_id,
-						 GError		**error);
+						 GError		**error)
+						 G_GNUC_WARN_UNUSED_RESULT;
 
 G_END_DECLS
 
